@@ -2,10 +2,12 @@ OC.L10N.register(
     "contacts",
     {
     "Copy to full name" : "Скапіяваць у поўнае імя",
+    "Loading …" : "Загрузка …",
     "Rename" : "Перайменаваць",
     "Delete" : "Выдаліць",
     "Copy link" : "Скапіяваць спасылку",
     "Add" : "Дадаць",
+    "First name" : "Імя",
     "Password protection" : "Абарона паролем",
     "Save" : "Захаваць",
     "Settings" : "Налады",
@@ -13,6 +15,7 @@ OC.L10N.register(
     "Add contact to Birthday Calendar" : "Дадаць кантакт у каляндар дзён нараджэння",
     "Exclude contact from Birthday Calendar" : "Выключыць кантакт з календара дзён нараджэння",
     "Title" : "Загаловак",
+    "Edit" : "Рэдагаваць",
     "User" : "Карыстальнік",
     "Group" : "Група",
     "Email" : "Электронная пошта",
