@@ -95,7 +95,6 @@ OC.L10N.register(
     "Gender" : "Sex",
     "Female" : "Femeie",
     "Male" : "Bărbat",
-    "Unknown" : "Necunoscut",
-    "Manager" : "Director"
+    "Unknown" : "Necunoscut"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
