@@ -3,17 +3,19 @@ OC.L10N.register(
     {
     "Contacts" : "Contacts",
     "Loading contacts …" : "Loading contacts …",
-    "Rename" : "Rename",
-    "Delete" : "Delete",
-    "Download" : "Download",
+    "Rename" : "Nomini o'zgartirish",
+    "Delete" : "O'chirish",
+    "Download" : "Yuklab olish",
     "Add" : "Qo'shish",
-    "Save" : "Save",
+    "Save" : "Saqlash",
     "Settings" : "Sozlamalar",
-    "Cancel" : "Cancel",
+    "Cancel" : "Bekor qilish",
     "Invalid image" : "Invalid image",
     "Name" : "Name",
     "Search contacts …" : "Search contacts …",
     "Pending" : "Pending",
+    "None" : "Yo'q",
+    "Close" : "Yopish",
     "Member" : "Member",
     "Admin" : "Admin",
     "Users" : "Users",
