@@ -160,13 +160,17 @@ OC.L10N.register(
     "Calendar events with you" : "与您分享的日历事件",
     "Deck cards with you" : "与您分享的卡片",
     "No shared items with this contact" : "与该联系人无共享项目",
+    "_Delete {number} contact_::_Delete {number} contacts_" : ["删除 {number} 位联系人"],
+    "Please select at least one editable contact to delete" : "请至少选择一个可编辑的联系人进行删除",
+    "Are you sure you want to proceed?" : "是否确定要继续？",
     "Search contacts …" : "搜索联系人 ...",
+    "Unselect {number}" : "取消选择 {number}",
     "Add to {group}" : "添加到 {group}",
+    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "请注意，您只能将可写通讯录中的联系人添加到联系人组。无法添加只读通讯录（如系统通讯录）中的联系人。",
     "Remove {type}" : "移除 {type}",
     "Add to group" : "添加到群组",
     "Search {types}" : "搜索 {types}",
     "Search for people to add" : "搜索要添加的人",
-    "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "请注意，您只能将可写通讯录中的联系人添加到联系人组。无法添加只读通讯录（如系统通讯录）中的联系人。",
     "No results" : "无结果",
     "Add {type}" : "添加  {type}",
     "New team name" : "新团队名称",
